from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class UserBookBase(BaseModel):
    title: str = Field(..., description="Book title")
    author: str = Field(..., description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    genre: Optional[str] = Field(None, description="Book genre")
    pages: Optional[int] = Field(None, description="Number of pages")
    publisher_id: Optional[UUID] = Field(None, description="Publisher ID")

class UserBookCreate(UserBookBase):
    pass

class UserBookUpdate(UserBookBase):
    title: Optional[str] = Field(None, description="Book title")
    author: Optional[str] = Field(None, description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    genre: Optional[str] = Field(None, description="Book genre")
    pages: Optional[int] = Field(None, description="Number of pages")
    publisher_id: Optional[UUID] = Field(None, description="Publisher ID")

class UserBookSchema(UserBookBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True